@@ -3,12 +3,12 @@
 }
 
 .is_scalar_chr <- function(x, na_ok = FALSE) {
-    length(x) == 1L && is.character(x) && (na_ok || !is.na(x))
+    length(x) == 1L && is.character(x) && (na_ok || !is.na(x)) 		# #nocov
 }
 
 .drop_file_ext <- function(file_path, file_ext) {
     mapply(function(.file_path, .file_ext) {
-        if (nchar(.file_ext) == 0L) .file_path
+        if (nchar(.file_ext) == 0L) .file_path				# #nocov
         else sub(sprintf("%s$", .file_ext), "", .file_path)
     }, file_path, file_ext, USE.NAMES = FALSE)
 }
@@ -43,7 +43,8 @@
 
         temp_files <- rep(NA_character_, nrow(diagnosis))
         temp_files[diagnosis$is_from_url] <- tempfile(
-            pattern = .drop_file_ext(basename(diagnosis$input[diagnosis$is_from_url]), diagnosis$file_ext[diagnosis$is_from_url]),
+            pattern = .drop_file_ext(basename(gsub("[?]", "_", diagnosis$input[diagnosis$is_from_url])),
+                                     diagnosis$file_ext[diagnosis$is_from_url]),
             tmpdir = normalizePath(temp_dir),
             fileext = .fileext[diagnosis$is_from_url]
         )
@@ -60,7 +61,7 @@
             )
         }
 
-        if (any(diagnosis$is_remote_file_url)) {
+        if (any(diagnosis$is_remote_file_url)) {			# #nocov start
             .url <- diagnosis$input[diagnosis$is_remote_file_url]
             .destfile <- temp_files[diagnosis$is_remote_file_url]
 
@@ -81,7 +82,7 @@
                         destfile = .destfile,
                         method = .method,
                         quiet = !verbose,
-                        headers = .headers
+                        headers = .headers				# #nocov end
                     )
                 }
             }
